@@ -8,3 +8,7 @@ ds <- eigen(ret_cov)
 test_that("sqrtm uses spectral decomposition", {
   expect_equal(sqrtm(ret_cov), ds$vectors %*% diag(sqrt(ds$values)) %*% t(ds$vectors))
 })
+
+test_that("sqrtm only work with quadratic objects", {
+  expect_error(sqrtm(matrix(stats::rnorm(6), ncol = 2)))
+})
